@@ -5,7 +5,7 @@ From http://blog.jeffbalogh.org/post/57653515/nose-test-runner-for-django
 
 Setup:
      In settings.py:
-     TEST_RUNNER = ‘django_satprep.nose_runner.run_tests’
+     TEST_RUNNER = 'django_satprep.nose_runner.run_tests'
 
 Usage:
     ./manage.py test DJANGO_ARGS -- NOSE_ARGS
@@ -87,4 +87,3 @@ def run_tests(test_labels, verbosity=1, interactive=True, extra_tests=[]):
     # Clean up django.
     connection.creation.destroy_test_db(old_db_name, verbosity)
     teardown_test_environment(teardown_funcs)
-
